#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
@文件名称: generate_local_settings.py
@功能描述: 自动生成 Django 本地配置文件（local_settings.py）
@参数说明: 无
@依赖环境: Python >= 3.6
@使用方法: python generate_local_settings.py
"""
import os
import re
import sys
from pathlib import Path


def get_env_from_bashrc():
    """从.bashrc文件中提取环境变量"""
    env_vars = {}
    bashrc_path = os.path.expanduser('~/.bashrc')
    
    if not os.path.exists(bashrc_path):
        return env_vars
    
    with open(bashrc_path, 'r') as f:
        content = f.read()
    
    # 匹配 export VAR="value" 或 export VAR='value'
    pattern = re.compile(r'export\s+([A-Z_]+)=["\']([^"\']+)["\']')
    matches = pattern.findall(content)
    
    for var, value in matches:
        env_vars[var] = value
    
    return env_vars


def get_project_name():
    """获取当前Django项目的名称"""
    try:
        # 尝试从环境变量获取
        project_name = os.getenv('DJANGO_PROJECT_NAME')
        if project_name:
            return project_name
        
        # 尝试从当前目录结构判断
        manage_py = Path.cwd() / 'manage.py'
        if manage_py.exists():
            # 标准Django项目结构: project_name/manage.py
            return Path.cwd().name
        
        # 查找settings.py的父目录名
        settings_path = find_settings_file()
        if settings_path.parent.name == settings_path.parent.parent.name:
            return settings_path.parent.name  # project_name/project_name/settings.py
        return settings_path.parent.name     # project_dir/settings.py
    
    except Exception:
        return 'myproject'  # 默认值


def find_settings_file():
    """查找settings.py文件路径"""
    search_paths = [Path.cwd()] + list(Path.cwd().parents)[:3]
    for base_dir in search_paths:
        # 标准结构：project_name/project_name/settings.py
        standard_path = base_dir / base_dir.name / "settings.py"
        if standard_path.exists():
            return standard_path
        # 单层结构：base_dir/settings.py
        if (base_dir / "settings.py").exists():
            return base_dir / "settings.py"
    raise FileNotFoundError("未找到 settings.py 文件")


def generate_local_settings():
    try:
        # 获取环境变量
        env_vars = get_env_from_bashrc()
        mysql_password = env_vars.get('MYSQL_ROOT_PASS', 'Chan1996!')
        redis_password = env_vars.get('REDIS_PASSWORD', 'chanjian8888')
        project_name = get_project_name()
        
        # 获取服务器IP（简化版，不再依赖requests）
        server_ip = '127.0.0.1'
        try:
            import socket
            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            s.connect(('8.8.8.8', 80))
            server_ip = s.getsockname()[0]
            s.close()
        except:
            pass
        
        settings_dir = find_settings_file().parent
        
        content = f"""
DEBUG = False

ALLOWED_HOSTS = ['{server_ip}', 'localhost', '127.0.0.1']

DATABASES = {{
    'default': {{
        'ENGINE': 'django.db.backends.mysql',
        'NAME': '{project_name}',
        'USER': 'root',
        'PASSWORD': '{mysql_password}',
        'HOST': '127.0.0.1',
        'PORT': 3306,
        'OPTIONS': {{
            'init_command': "SET sql_mode='STRICT_TRANS_TABLES'",
        }}
    }}
}}

CACHES = {{
    "default": {{
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": "redis://127.0.0.1:6379/0",
        "OPTIONS": {{
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
            "CONNECTION_POOL_KWARGS": {{"max_connections": 100}},
            "PASSWORD": "{redis_password}",
        }}
    }}
}}

# Static files (CSS, JavaScript, Images)
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATIC_URL = '/static/'
"""

        output_path = settings_dir / "local_settings.py"
        with open(output_path, 'w', encoding='utf-8') as f:
            f.write(content.strip())
        print(f"✔ 本地配置文件已生成: {output_path}")
        
    except Exception as e:
        print(f"错误: {e}")
        sys.exit(1)


if __name__ == "__main__":
    generate_local_settings()